--[[
 Displays range to the target, and displays a target's target window

 Type /targetrange for options

 by Balyn (boggrak@hotmail.com)

 Last update: 08/25/2007

 Release of Target Range

 Version 1.33
]]

local vardb = {};
local varDebug = false;

local TargetTarget_LastTT = nil;
local targetsTargetName = nil;

local rangedb;
rangedb = {};
for i= 1,20 do
  rangedb[i] = {};
end


function TargetRange_OnLoad()

  TargetRangeUsers = {};

  SlashCmdList["TARGETRANGE"] = TargetRange_ChatCommand;
  SLASH_TARGETRANGE1 = "/targetrange";

  this:RegisterEvent("PLAYER_TARGET_CHANGED");
  this:RegisterEvent("UNIT_TARGET");
  this:RegisterEvent("VARIABLES_LOADED");
  this:RegisterEvent("PLAYER_ALIVE");
  this:RegisterEvent("UNIT_INVENTORY_CHANGED");
  this:RegisterEvent("ACTIONBAR_UPDATE_USABLE");

  TargetRangeTip:SetOwner(WorldFrame, "ANCHOR_NONE");

  if(DEFAULT_CHAT_FRAME) then
    DEFAULT_CHAT_FRAME:AddMessage("Loaded TargetRange 1.33 by Balyn. Type /targetrange for commands.");
  end

end


function TargetRange_ChatCommand(msg)
  local cmd = msg;
  local pos, _, param = string.find(msg, " (.+)");
  if (param) then
    cmd = string.sub(msg, 1, pos - 1);
  else
    param = "nil";
  end

  if msg == "" or cmd == "help" or cmd == "hilfe" or cmd == "?" then
    for i = 1, table.getn(TARGETRANGE_HELP) do
      TargetRange_ChatMessage(TARGETRANGE_HELP[i]);
    end
  elseif cmd == "show" then
    vardb.targetShow = true;
    vardb.rangeShow = true;     
    TargetRange_ChatMessage("Range & Target Windows Enabled");
    TargetRange_SetupUser();
  elseif cmd == "hide" then
    vardb.targetShow = false;
    vardb.rangeShow = false;     
    TargetRange_ChatMessage("Range & Target Windows Disabled");
    TargetRange_SetupUser();
  elseif cmd == "lock" then
    vardb.locked = (cmd == "lock");
    TargetRange_Lock(true);
  elseif cmd == "unlock" then
    vardb.locked = (cmd == "lock");
    TargetRange_Unlock(true);
  elseif cmd == "fade" then
    vardb.windowFade = (not vardb.windowFade);
    if (vardb.windowFade == true) then
      TargetRange_ChatMessage("Window Fade Enabled");
      if (vardb.locked == false) then 
        TargetRange_ChatMessage("Must type /targetrange lock for fade to work");     
      end
    else
      TargetRange_ChatMessage("Window Fade Disabled");
    end
    TargetRange_SetupUser();
  elseif cmd == "fontsize" then
--    local _, _, newHeight = string.find(cmd, "fontsize (%d+)");
    TargetRange_SetTextHeight(param);
  elseif cmd == "status" then
    TargetRange_PrintStatus();
  elseif cmd == "alpha" then
    TargetRange_SetAlpha(param);
  elseif cmd == "update" then
    TargetRange_SetUpdateInterval(param);
  elseif cmd == "debug" then
    varDebug = not varDebug;
--    if varDebug then
--      vardb.rangedb = rangedb;
--    end
  elseif cmd == "center" then
    TargetRange_Center();
  elseif cmd == "target" then
    if vardb.targetShow == true then
      vardb.targetShow = false;
      TargetRange_ChatMessage("Target's Target Window Disabled");
      TargetRange_SetupUser();
    else
      vardb.targetShow = true;
      TargetRange_ChatMessage("Target's Target Window Enabled");
      TargetRange_SetupUser();
    end
  elseif cmd == "targetsize" then
    TargetRange_SetTargetSize(param);
  elseif cmd == "range" then
    if vardb.rangeShow == true then
      vardb.rangeShow = false;
      TargetRange_ChatMessage("Range Window Disabled");
      TargetRange_SetupUser();
    else
      vardb.rangeShow = true;
      TargetRange_ChatMessage("Range Window Enabled");
      TargetRange_SetupUser();
    end 
  elseif cmd == "rl" then
    ReloadUI();
  else
    TargetRange_ChatMessage(TARGETRANGE_UNKNOWN_COMMAND);
  end

end
    

function TargetRange_OnEvent(event)

  HRDebug(event);
  if (event == "PLAYER_TARGET_CHANGED") or (event == "UNIT_TARGET") then	
    if vardb.targetShow then
      TargetTarget_Update();
    end
    TargetRangeFade();

    if vardb.rangeShow then
      TargetRange_SetRangeVars();
      TargetRange_GetRange();
    end
  end
 
  if event == "VARIABLES_LOADED" then
    TargetRange_SetupUser();
  end
  if (event == "PLAYER_ALIVE") then
    TargetRange_SetRangeVars();
    TargetRangeFade() ;
  end
  if (event == "UNIT_INVENTORY_CHANGED") then
    TargetRange_SetRangeVars();
  end
  if (event == "ACTIONBAR_UPDATE_USABLE") then
    TargetRange_SetRangeVars();
  end


end
    
local TargetRangeTimeSinceLastUpdate = 0;
vardb.updateInterval = 0.05;

function TargetRange_OnUpdate(elapsed)
  TargetRangeTimeSinceLastUpdate = TargetRangeTimeSinceLastUpdate + elapsed;
  if (TargetRangeTimeSinceLastUpdate > vardb.updateInterval) then
    
    if vardb.rangeShow or vardb.targetShow then
      TargetRange_GetRange();
    end

    TargetRangeTimeSinceLastUpdate = 0;
  end

end

function TargetTarget_Update()
--  if(UnitIsFriend("player", "playertarget")) then -- only check for hostile targets
--    TargetRangeSetNoTarget();
--    TargetTarget_LastTT = nil;
--    targetsTargetName = "";
--    return;
--  end
    
  if(UnitIsUnit("player", "playertargettarget")) then --targets target is the player        
    TargetRangeSetTargetIsTarget()
  elseif(UnitExists("playertargettarget")) then --targets target is not the player
    TargetRangeSetTargetIsNotTarget();		
  elseif((not UnitExists("playertargettarget"))) then --there is no targets target
    TargetRangeSetNoTarget();		
  end

end

function TargetRangeSetTargetIsTarget() -- set target frame to *** YOU ***
    if(TargetTarget_LastTT ~= "player") then
      targetsTargetName = TRLocale.OTHER.You;
      TargetTarget_LastTT = "player";
      TargetRange_TargetSize(vardb.targetlength);
      TargetRangeWatchFrame2String2:SetTextColor(1.0, 0.0, 0.0); --Red
      TargetRangeWatchFrame2String2:SetText(targetsTargetName);
    end
end

function TargetRangeSetTargetIsNotTarget() -- set target frame to target's target
    if(TargetTarget_LastTT ~= UnitName("playertargettarget")) then        
      targetsTargetName = UnitName("playertargettarget");
      TargetTarget_LastTT = UnitName("playertargettarget");
      TargetRange_TargetSize(vardb.targetlength);
      TargetRangeWatchFrame2String2:SetTextColor(0.0, 1.0, 0.0); --Green
      TargetRangeWatchFrame2String2:SetText(targetsTargetName);
    end
end

function TargetRangeSetNoTarget() -- clear Target frame
    if(TargetTarget_LastTT ~= nil) then
      targetsTargetName = "";
      TargetTarget_LastTT = nil;
      TargetRange_TargetSize(vardb.targetlength);
      TargetRangeWatchFrame2String2:SetText(targetsTargetName);
    end
end


function TargetRangeFade() -- Fade frame when no target option
  if (vardb.targetShow) or (vardb.rangeShow) then
    if (vardb.windowFade == true) and (vardb.locked == true) then
      if UnitExists("playertarget") then
        TargetRangeFrame:Show();
        TargetRangeWatchFrame:Show();
--        TargetRange_ChatMessage("Target Acquired");
      else
        TargetRangeFrame:Hide();
        TargetRangeWatchFrame:Hide();
--        TargetRange_ChatMessage("Target Cleared");
      end
    end
  end
end


function TargetRange_SetupUser()

  HRDebug("func: TargetRange_SetupUser"); 
  local vardbName = UnitName("player") .. "|" .. GetCVar("realmName"); 
  vardb = {};

  if TargetRangeUsers[vardbName] == nil then
    HRDebug("UserDatabse is Nil");
    TargetRangeUsers[vardbName] = { show = true,
       				    alpha = 1.00,
                                  locked = false,
                                  textHeight = 12,
                                  windowFade = false,
                                  rangeShow = true,
                                  targetShow = true,
                                  targetLength = 9,
                                  updateInterval = 0.15 };
                                     
  end

  vardb = TargetRangeUsers[vardbName];

  if vardb.updateInterval == nil then 
    vardb.updateInterval = 0.15;
  end
  if vardb.targetShow == nil then
    vardb.targetShow = true;
    vardb.alpha = 1.00;
    TargetRange_Center();    
  end
  if vardb.targetLength == nil then
    vardb.targetLength = 9;
  end
  if vardb.rangeShow == nil then
    vardb.rangeShow = true;
    vardb.show = nil;
  end
  if vardb.windowFade == nil then
    vardb.windowFade = false;
  end

  TargetRange_SetAlpha(vardb.alpha);
  TargetRange_SetTextHeight(vardb.textHeight); 
  TargetRange_SetUpdateInterval(vardb.updateInterval);
  TargetRange_RangeSize();
  TargetRange_TargetSize(vardb.targetlength);
  if vardb.locked then
    TargetRange_Lock(false);
  else
    TargetRange_Unlock(false);
  end
  
  if vardb.rangeShow or vardb.targetShow then
    TargetRangeFrame:Show();
    TargetRangeWatchFrame:Show();

    if vardb.rangeShow then
      TargetRangeWatchFrame1:Show();
    else
      TargetRangeWatchFrame1:Hide();
    end

    if vardb.targetShow then
      TargetRangeWatchFrame2:Show();
    else
      TargetRangeWatchFrame2:Hide();
    end
  else
    TargetRangeFrame:Hide();
    TargetRangeWatchFrame:Hide();
  end
  TargetRange_SetRangeVars();
  TargetRangeFade() ;
end

function TargetRange_SetRangeVars()

  for i= 1,20 do
    rangedb[i].MinDistance = 0;
    rangedb[i].Distance = 0;
    rangedb[i].Action = 0;
    rangedb[i].Color = "Gray";
    rangedb[i].IsAction = true;
    rangedb[i].InRange = false;
    rangedb[i].IsValid = false;
    rangedb[i].SpellName = "N/A";
    rangedb[i].DisplayName = "N/A";
  end

  local _, playerClass = UnitClass("player");

  if (playerClass == "ROGUE") or (playerClass == "HUNTER") or (playerClass == "WARRIOR") 
      or (playerClass == "MAGE") or (playerClass == "WARLOCK") then
    rangedb[10].MinDistance = 0;
    rangedb[10].Distance = 7;
    rangedb[10].Action = 3;
    rangedb[10].IsAction = false;
    rangedb[10].Color = "Green";
    rangedb[10].SpellName = "Duel";
    rangedb[10].DisplayName = TRLocale.OTHER.Friend;

    rangedb[11].MinDistance = 7;
    rangedb[11].Distance = 28;
    rangedb[11].Action = 4;
    rangedb[11].IsAction = false;
    rangedb[11].Color = "Yellow";
    rangedb[11].SpellName = "Follow";
    rangedb[11].DisplayName = TRLocale.OTHER.Friend;

    rangedb[12].MinDistance = 28;
    rangedb[12].Distance = 100;
    rangedb[12].Color = "Red";
    rangedb[12].SpellName = "Out of Range";
    rangedb[12].DisplayName = TRLocale.OTHER.Friend;

  end


  if (playerClass == "PRIEST") then

    rangedb[10].MinDistance = 0;
    rangedb[10].Distance = 7;
    rangedb[10].Action = 3;
    rangedb[10].IsAction = false;
    rangedb[10].Color = "Green";
    rangedb[10].SpellName = "Duel";
    rangedb[10].DisplayName = TRLocale.PRIEST.Heal;

    rangedb[11].MinDistance = 7;
    rangedb[11].Distance = 28;
    rangedb[11].Action = 4;
    rangedb[11].IsAction = false;
    rangedb[11].Color = "Yellow";
    rangedb[11].SpellName = "Follow";
    rangedb[11].DisplayName = TRLocale.PRIEST.Heal;

    rangedb[12].MinDistance = 28;
    rangedb[12].Distance = 40;
    rangedb[12].Color = "Orange";
    rangedb[12].SpellName = TRLocale.PRIEST.Heal;
    rangedb[12].DisplayName = TRLocale.OTHER.Max_Heal;

    rangedb[13].MinDistance = 40;
    rangedb[13].Distance = 100;
    rangedb[13].Color = "Red";
    rangedb[13].SpellName = "Out of Range";
    rangedb[13].DisplayName = TRLocale.OTHER.Too_Far;

  end


  if (playerClass == "SHAMAN") then

    rangedb[10].MinDistance = 0;
    rangedb[10].Distance = 7;
    rangedb[10].Action = 3;
    rangedb[10].IsAction = false;
    rangedb[10].Color = "Green";
    rangedb[10].SpellName = "Duel";
    rangedb[10].DisplayName = TRLocale.PRIEST.Heal;

    rangedb[11].MinDistance = 7;
    rangedb[11].Distance = 30;
    rangedb[11].Color = "Yellow";
    rangedb[11].SpellName = TRLocale.SHAMAN.Water_Breathing;
    rangedb[11].DisplayName = TRLocale.PRIEST.Heal;

    rangedb[12].MinDistance = 30;
    rangedb[12].Distance = 40;
    rangedb[12].Color = "Orange";
    rangedb[12].SpellName = TRLocale.SHAMAN.Healing_Wave;
    rangedb[12].DisplayName = TRLocale.OTHER.Max_Heal;

    rangedb[13].MinDistance = 40;
    rangedb[13].Distance = 100;
    rangedb[13].Color = "Red";
    rangedb[13].SpellName = "Out of Range";
    rangedb[13].DisplayName = TRLocale.OTHER.Too_Far;

  end

  if (playerClass == "PALADIN") then

    --Check Holy Shock
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(1,17);
    local hasHolyShock = currRank;

    rangedb[10].MinDistance = 0;
    rangedb[10].Distance = 7;
    rangedb[10].Action = 3;
    rangedb[10].IsAction = false;
    rangedb[10].Color = "Green";
    rangedb[10].SpellName = "Duel";
    rangedb[10].DisplayName = TRLocale.PRIEST.Heal;

    if (hasHolyShock == 1) then
      rangedb[11].MinDistance = 7;
      rangedb[11].Distance = 20;
      rangedb[11].Color = "Yellow";
      rangedb[11].SpellName = TRLocale.PALADIN.Holy_Shock;
      rangedb[11].DisplayName = TRLocale.PALADIN.Display_Holy_Shock;
    end

    rangedb[12].MinDistance = 7;
    rangedb[12].Distance = 30;
    rangedb[12].Color = "Yellow";
    if (hasHolyShock == 1) then 
      rangedb[12].MinDistance = 20;
    end
    rangedb[12].SpellName = TRLocale.PALADIN.Blessing_of_Might;
    rangedb[12].DisplayName = TRLocale.PALADIN.Blessing_of_Might_Display;

    rangedb[13].MinDistance = 30;
    rangedb[13].Distance = 40;
    rangedb[13].Color = "Orange";
    rangedb[13].SpellName = TRLocale.PALADIN.Holy_Light;
    rangedb[13].DisplayName = TRLocale.OTHER.Max_Heal;

    rangedb[14].MinDistance = 40;
    rangedb[14].Distance = 100;
    rangedb[14].Color = "Red";
    rangedb[14].SpellName = "Out of Range";
    rangedb[14].DisplayName = TRLocale.OTHER.Too_Far;

  end

  if (playerClass == "DRUID") then

    rangedb[10].MinDistance = 0;
    rangedb[10].Distance = 7;
    rangedb[10].Action = 3;
    rangedb[10].IsAction = false;
    rangedb[10].Color = "Green";
    rangedb[10].SpellName = "Duel";
    rangedb[10].DisplayName = TRLocale.PRIEST.Heal;

    rangedb[11].MinDistance = 7;
    rangedb[11].Distance = 30;
    rangedb[11].Color = "Yellow";
    rangedb[11].SpellName = TRLocale.DRUID.Mark_of_the_Wild;
    rangedb[11].DisplayName = TRLocale.PRIEST.Heal;

    rangedb[12].MinDistance = 30;
    rangedb[12].Distance = 40;
    rangedb[12].Color = "Orange";
    rangedb[12].SpellName = TRLocale.DRUID.Healing_Touch;
    rangedb[12].DisplayName = TRLocale.OTHER.Max_Heal;

    rangedb[13].MinDistance = 40;
    rangedb[13].Distance = 100;
    rangedb[13].Color = "Red";
    rangedb[13].SpellName = "Out of Range";
    rangedb[13].DisplayName = TRLocale.OTHER.Too_Far;

  end



  if playerClass == "ROGUE" then

    rangedb[1].MinDistance = 0;
    rangedb[1].Distance = 5;
    rangedb[1].Color = "Green";
    rangedb[1].SpellName = TRLocale.ROGUE.Sinister_Strike;
    rangedb[1].DisplayName = TRLocale.OTHER.Melee;

    rangedb[2].MinDistance = 5;
    rangedb[2].Distance = 10;
    rangedb[2].Color = "Yellow";
    rangedb[2].SpellName = TRLocale.ROGUE.Blind;
    rangedb[2].DisplayName = TRLocale.ROGUE.Blind;

    rangedb[3].MinDistance = 10;
    rangedb[3].Distance = 30;
    rangedb[3].Color = "Orange";
    rangedb[3].SpellName = TRLocale.ROGUE.Throw;
    rangedb[3].DisplayName = TRLocale.WARRIOR.Shoot;

    rangedb[4].MinDistance = 30;
    rangedb[4].Distance = 100;
    rangedb[4].Color = "Red";
    rangedb[4].SpellName = TRLocale.ROGUE.Slice_and_Dice;
    rangedb[4].DisplayName = TRLocale.OTHER.Too_Far;

  end


  if playerClass == "MAGE" then

    --Check if mage has the 5 yards extended fire blast range from the gladiator gloves
    local HandsSlotLink = GetInventoryItemLink("player",GetInventorySlotInfo("HandsSlot"));
    local ExtendedRangeGloves;

    if (HandsSlotLink == nil) then
      ExtendedRangeGloves = 0;
    else
      local itemName = GetItemInfo(HandsSlotLink);
      if ((itemName == TRLocale.MAGE.Arena2_Gloves) or (itemName == TRLocale.MAGE.Arena1_Gloves)) then
        ExtendedRangeGloves = 5;
      else
        ExtendedRangeGloves = 0;
      end
    end

    --Check Flame Throwing rank and set number to bonus yards
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(2,4);
    local FlameThrowBonus = currRank * 3;

    --Check Arctic Reach rank and set to bonus range percent
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(3,11);
    local ArcticBonus = 1 + currRank * .1;

    rangedb[1].MinDistance = 0;
    rangedb[1].Distance = 5;
    rangedb[1].Action = 3;
    rangedb[1].IsAction = false;
    rangedb[1].Color = "Red";
    rangedb[1].SpellName = "Duel";
    rangedb[1].DisplayName = TRLocale.OTHER.Melee;

    rangedb[2].MinDistance = 5;    
    rangedb[2].Distance = 20 + FlameThrowBonus + ExtendedRangeGloves;
    rangedb[2].Color = "Green";
    rangedb[2].SpellName = TRLocale.MAGE.Fire_Blast;
    rangedb[2].DisplayName = TRLocale.MAGE.Fire_Blast;

    if (ExtendedRangeGloves == 0) then
      rangedb[3].MinDistance = rangedb[2].Distance;
      rangedb[3].Distance = 30;
      rangedb[3].Color = "Green";
      rangedb[3].SpellName = TRLocale.MAGE.Arcane_Missiles;
      rangedb[3].DisplayName = TRLocale.MAGE.Arcane_Missiles_Display;
    else
      rangedb[3].Distance = rangedb[2].Distance;
    end

    if (FlameThrowBonus > 0) then
      rangedb[4].MinDistance = rangedb[3].Distance;
      rangedb[4].Distance = 30 + FlameThrowBonus;
      rangedb[4].Color = "Yellow";
      rangedb[4].SpellName = TRLocale.MAGE.Scorch;
      rangedb[4].DisplayName = TRLocale.MAGE.Scorch;
    elseif (ArcticBonus > 1) then
      rangedb[4].MinDistance = rangedb[3].Distance;
      rangedb[4].Distance = 30 * ArcticBonus;
      rangedb[4].Color = "Yellow";
      rangedb[4].SpellName = TRLocale.MAGE.Frostbolt;
      rangedb[4].DisplayName = TRLocale.MAGE.Frostbolt;
    end

    rangedb[5].MinDistance = rangedb[3].Distance;
    if (FlameThrowBonus > 0) or (ArcticBonus > 1) then 
      rangedb[5].MinDistance = rangedb[4].Distance;
    end
    rangedb[5].Distance = 35 + FlameThrowBonus;
    rangedb[5].Color = "Orange";
    rangedb[5].SpellName = TRLocale.MAGE.Fireball;
    rangedb[5].DisplayName = TRLocale.MAGE.Fireball;

    if (FlameThrowBonus == 0) and (ArcticBonus == 1) then 
      rangedb[6].MinDistance = 35;
      rangedb[6].Distance = 40;
      rangedb[6].Color = "Blue";
      rangedb[6].SpellName = TRLocale.MAGE.Detect_Magic;
      rangedb[6].DisplayName = TRLocale.MAGE.Detect_Magic;
    end

    rangedb[7].MinDistance = 40;
    if (FlameThrowBonus > 0) or (ArcticBonus > 1) then 
      rangedb[7].MinDistance = rangedb[5].Distance;
    end
    rangedb[7].Distance = 100;
    rangedb[7].Color = "Red";
    rangedb[7].SpellName = "Out of Range";
    rangedb[7].DisplayName = TRLocale.OTHER.Too_Far;
  
  end


  if playerClass == "HUNTER" then

    --Check Hawkeye rank and set to number of bonus yards
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(3,3);
    local HawkeyeBonus = currRank * 2;

    --Check ScatterShot
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(2,12);
    local ScatterShot = currRank;

    rangedb[1].MinDistance = 0;
    rangedb[1].Distance = 5;
    rangedb[1].Color = "Orange";
    rangedb[1].SpellName = TRLocale.HUNTER.Wing_Clip;
    rangedb[1].DisplayName = TRLocale.OTHER.Melee;

    rangedb[2].MinDistance = 5;
    rangedb[2].Distance = 8;
    rangedb[2].Action = 3;
    rangedb[2].Color = "Red";
    rangedb[2].SpellName = TRLocale.OTHER.Deadzone;
    rangedb[2].DisplayName = TRLocale.OTHER.Deadzone;

    rangedb[3].MinDistance = 8;
    rangedb[3].Distance = 15 + HawkeyeBonus;
    rangedb[3].Color = "Yellow";

    if (ScatterShot == 0) then 
      rangedb[3].SpellName = "N/A";
      rangedb[4].MinDistance = 8;
    else
      rangedb[3].SpellName = TRLocale.HUNTER.Scatter_Shot;
      rangedb[3].DisplayName = TRLocale.HUNTER.Scatter_Shot;
      rangedb[4].MinDistance = rangedb[3].Distance;
    end

    rangedb[4].Distance = 28;
    rangedb[4].Action = 4;
    rangedb[4].IsAction = false;
    rangedb[4].Color = "Green";
    rangedb[4].SpellName = "Can Follow";
    rangedb[4].DisplayName = TRLocale.WARRIOR.Shoot;

    rangedb[5].MinDistance = 28;
    rangedb[5].Distance = 35 + HawkeyeBonus;
    rangedb[5].Color = "Orange";
    rangedb[5].SpellName = TRLocale.HUNTER.Auto_Shot;
    rangedb[5].DisplayName = TRLocale.WARRIOR.Shoot;

    rangedb[6].MinDistance = rangedb[5].Distance;
    rangedb[6].Distance = 100;
    rangedb[6].Color = "Red";
    rangedb[6].SpellName = TRLocale.HUNTER.Hunters_Mark;
    rangedb[6].DisplayName = TRLocale.HUNTER.Hunters_Mark_Display;
  
  end


  if playerClass == "WARRIOR" then

    rangedb[1].MinDistance = 0;
    rangedb[1].Distance = 5;
    rangedb[1].Color = "Green";
    rangedb[1].SpellName = TRLocale.WARRIOR.Hamstring;
    rangedb[1].DisplayName = TRLocale.OTHER.Melee;

    rangedb[2].MinDistance = 5;
    rangedb[2].Distance = 10;
    rangedb[2].Color = "Yellow";
    rangedb[2].SpellName = TRLocale.WARRIOR.Intimidating_Shout;
    rangedb[2].DisplayName = TRLocale.WARRIOR.Intimidating_Shout_Display;

    rangedb[3].MinDistance = 10;
    rangedb[3].Distance = 25;
    rangedb[3].Color = "Blue";
    rangedb[3].SpellName = TRLocale.WARRIOR.Charge;
    rangedb[3].DisplayName = TRLocale.WARRIOR.Charge;

    rangedb[4].MinDistance = 25;
    rangedb[4].Distance = 30;
    rangedb[4].Color = "Orange";
    rangedb[4].SpellName = TRLocale.WARRIOR.Shoot;
    rangedb[4].DisplayName = TRLocale.WARRIOR.Shoot;

    rangedb[5].MinDistance = 30;
    rangedb[5].Distance = 100;
    rangedb[5].Color = "Red";
    rangedb[5].SpellName = "Out of Range";
    rangedb[5].DisplayName = TRLocale.OTHER.Too_Far;
  
  end

  
  if playerClass == "WARLOCK" then

    --Check Grim Reach rank and set to bonus range percent
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(1,10);
    local GrimBonus = 1 + currRank * .1;

    --Check Destructive Reach rank and set to bonus range percent
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(3,10);
    local DestrBonus = 1 + currRank * .1;

    rangedb[1].MinDistance = 0;
    rangedb[1].Distance = 5;
    rangedb[1].Action = 3;
    rangedb[1].IsAction = false;
    rangedb[1].Color = "Green";
    rangedb[1].SpellName = "Duel";
    rangedb[1].DisplayName = TRLocale.OTHER.Melee;

    rangedb[2].MinDistance = 5;
    rangedb[2].Distance = 20 * GrimBonus;
    rangedb[2].Color = "Blue";
    rangedb[2].SpellName = TRLocale.WARLOCK.Fear;
    rangedb[2].DisplayName = TRLocale.WARLOCK.Fear;

    if (GrimBonus > 1) and (DestrBonus == 1) then 
      rangedb[3].MinDistance = rangedb[2].Distance;
      rangedb[3].Distance = 30;
      rangedb[3].Color = "Yellow";
      rangedb[3].SpellName = TRLocale.WARLOCK.Immolate;
      rangedb[3].DisplayName = TRLocale.WARLOCK.Immolate_Display;

      rangedb[4].MinDistance = 30;
      rangedb[4].Distance = 30 * GrimBonus;
      rangedb[4].Color = "Orange";
      rangedb[4].SpellName = TRLocale.WARLOCK.Corruption;
      rangedb[4].DisplayName = TRLocale.WARLOCK.Corruption_Display;

      rangedb[5].MinDistance = rangedb[4].Distance;
      rangedb[5].Distance = 100;
      rangedb[5].Color = "Red";
      rangedb[5].SpellName = "Out of Range";
      rangedb[5].DisplayName = TRLocale.OTHER.Too_Far;
    elseif (DestrBonus > 1) and (GrimBonus == 1) then
      rangedb[3].MinDistance = rangedb[2].Distance;
      rangedb[3].Distance = 30;
      rangedb[3].Color = "Yellow";
      rangedb[3].SpellName = TRLocale.WARLOCK.Corruption;
      rangedb[3].DisplayName = TRLocale.WARLOCK.Corruption_Display;

      rangedb[4].MinDistance = 30;
      rangedb[4].Distance = 30 * DestrBonus;
      rangedb[4].Color = "Orange";
      rangedb[4].SpellName = TRLocale.WARLOCK.Immolate;
      rangedb[4].DisplayName = TRLocale.WARLOCK.Immolate_Display;

      rangedb[5].MinDistance = rangedb[4].Distance;
      rangedb[5].Distance = 100;
      rangedb[5].Color = "Red";
      rangedb[5].SpellName = "Out of Range";
      rangedb[5].DisplayName = TRLocale.OTHER.Too_Far;
    else
      rangedb[3].MinDistance = rangedb[2].Distance;
      rangedb[3].Distance = 30 * DestrBonus;
      rangedb[3].Color = "Yellow";
      rangedb[3].SpellName = TRLocale.WARLOCK.Shadow_Bolt;
      rangedb[3].DisplayName = TRLocale.WARLOCK.Shadow_Bolt;

      rangedb[4].MinDistance = rangedb[3].Distance;
      rangedb[4].Distance = 100;
      rangedb[4].Color = "Red";
      rangedb[4].SpellName = "Out of Range";
      rangedb[4].DisplayName = TRLocale.OTHER.Too_Far;

    end

  end

  
  if playerClass == "PRIEST" then

    --Check Mind Flay
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(3,8);
    local MindFlay = (currRank == 1);

    --Check Shadow Reach rank and set to bonus range percent
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(3,10);
    local ShadowReachBonus = 1 + currRank * .1;

    rangedb[1].MinDistance = 0;
    rangedb[1].Distance = 5;
    rangedb[1].Action = 3;
    rangedb[1].IsAction = false;
    rangedb[1].Color = "Green";
    rangedb[1].SpellName = "Duel";
    rangedb[1].DisplayName = TRLocale.OTHER.Melee;

    if (MindFlay) then
      rangedb[2].MinDistance = 5;
      rangedb[2].Distance = 20 * ShadowReachBonus;
      rangedb[2].Color = "Yellow";
      rangedb[2].SpellName = TRLocale.PRIEST.Mind_Flay;
      rangedb[2].DisplayName = TRLocale.PRIEST.Mind_Flay;
    else
      rangedb[2].MinDistance = 5;
      rangedb[2].Distance = 20 * ShadowReachBonus;
      rangedb[2].Color = "Yellow";
      rangedb[2].SpellName = TRLocale.PRIEST.Mind_Control;
      rangedb[2].DisplayName = TRLocale.PRIEST.Mind_Control;
    end
   
    if (ShadowReachBonus > 1) then 
      rangedb[3].MinDistance = rangedb[2].Distance;
      rangedb[3].Distance = 30;
      rangedb[3].Color = "Orange";
      rangedb[3].SpellName = TRLocale.WARRIOR.Shoot;
      rangedb[3].DisplayName = TRLocale.WARRIOR.Shoot;
    end

    if (ShadowReachBonus > 1) then 
      rangedb[4].MinDistance = rangedb[3].Distance;
    else 
      rangedb[4].MinDistance = rangedb[2].Distance;
    end
    rangedb[4].Distance = 30 * ShadowReachBonus;
    rangedb[4].Color = "Orange";
    rangedb[4].SpellName = TRLocale.PRIEST.Mind_Blast;
    rangedb[4].DisplayName = TRLocale.PRIEST.Mind_Blast;

    rangedb[5].MinDistance = rangedb[4].Distance;
    rangedb[5].Distance = 100;
    rangedb[5].Color = "Red";
    rangedb[5].SpellName = TRLocale.PRIEST.Mind_Vision;
    rangedb[5].DisplayName = TRLocale.OTHER.Too_Far;

  end


  if playerClass == "SHAMAN" then

    --Check Storm Reach rank and set number to bonus yards
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(1,12);
    local StormReachBonus = currRank * 3;
    
    --Check if shaman has the 5 yards extended shock range from the gladiator gloves
    local ExtendedRangeGloves;
    local HandsSlotLink = GetInventoryItemLink("player",GetInventorySlotInfo("HandsSlot"));

    if (HandsSlotLink == nil) then
      ExtendedRangeGloves = 0;
    else
      local itemName = GetItemInfo(HandsSlotLink);
      if ((itemName == TRLocale.SHAMAN.Arena2_Gloves) or (itemName == TRLocale.SHAMAN.Arena1_Gloves)) then
        ExtendedRangeGloves = 5;
      else
        ExtendedRangeGloves = 0;
      end
    end
    --DEFAULT_CHAT_FRAME:AddMessage(itemName);

    rangedb[1].MinDistance = 0;
    rangedb[1].Distance = 5;
    rangedb[1].Action = 3;
    rangedb[1].IsAction = false;
    rangedb[1].Color = "Green";
    rangedb[1].SpellName = "Duel";
    rangedb[1].DisplayName = TRLocale.OTHER.Melee;

    rangedb[2].MinDistance = 5;
    rangedb[2].Distance = 20 + ExtendedRangeGloves;
    rangedb[2].Color = "Yellow";
    rangedb[2].SpellName = TRLocale.SHAMAN.Earth_Shock;
    rangedb[2].DisplayName = TRLocale.SHAMAN.Earth_Shock_Display;

    rangedb[3].MinDistance = rangedb[2].Distance;
    rangedb[3].Distance = 30 + StormReachBonus;
    rangedb[3].Color = "Orange";
    rangedb[3].SpellName = TRLocale.SHAMAN.Lightning_Bolt;
    rangedb[3].DisplayName = TRLocale.SHAMAN.Lightning_Bolt_Display;

    rangedb[4].MinDistance = rangedb[3].Distance;
    rangedb[4].Distance = 100;
    rangedb[4].Color = "Red";
    rangedb[4].SpellName = "Out of Range";
    rangedb[4].DisplayName = TRLocale.OTHER.Too_Far;

  end  

  if playerClass == "PALADIN" then

    --Check Crusader Strike 
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(3,22);
    local hasCrusaderStrike = currRank;
    --Check Repentance 
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(3,19);
    local hasRepentance = currRank;

    if (hasCrusaderStrike == 1) then
      rangedb[1].MinDistance = 0;
      rangedb[1].Distance = 5;
      rangedb[1].Color = "Green";
      rangedb[1].SpellName = TRLocale.PALADIN.Crusader_Strike;
      rangedb[1].DisplayName = TRLocale.OTHER.Melee;
    else
      rangedb[1].MinDistance = 0;
      rangedb[1].Distance = 5;
      rangedb[1].Action = 3;
      rangedb[1].IsAction = false;
      rangedb[1].Color = "Green";
      rangedb[1].SpellName = "Duel";
      rangedb[1].DisplayName = TRLocale.OTHER.Melee;
    end

    rangedb[2].MinDistance = 5;
    rangedb[2].Distance = 10;
    rangedb[2].Color = "Yellow";
    rangedb[2].SpellName = TRLocale.PALADIN.Hammer_of_Justice;
    rangedb[2].DisplayName = TRLocale.PALADIN.Hammer_of_Justice_Display;

    if (((hasRepentance == 1) and (UnitCreatureType("target") == "Humanoid")) or (hasHolyShock == 1)) then
      rangedb[3].MinDistance = 10;
      rangedb[3].Distance = 20;
      rangedb[3].Color = "Orange";
      if (hasRepentance == 1) then
        rangedb[3].SpellName = TRLocale.PALADIN.Repentance;
        rangedb[3].DisplayName = TRLocale.PALADIN.Repentance;
      end
      if (hasHolyShock == 1) then
        rangedb[3].SpellName = TRLocale.PALADIN.Holy_Shock;
        rangedb[3].DisplayName = TRLocale.PALADIN.Holy_Shock;
      end
    end

    rangedb[4].MinDistance = 10;
    if (((hasRepentance == 1) and (UnitCreatureType("target") == "Humanoid")) or (hasHolyShock == 1)) then
      rangedb[4].MinDistance = 20;
    end
    rangedb[4].Distance = 30;
    rangedb[4].Color = "Orange";
    rangedb[4].SpellName = TRLocale.PALADIN.Hammer_of_Wrath;
    rangedb[4].DisplayName = TRLocale.PALADIN.Hammer_of_Wrath_Display;

    rangedb[5].MinDistance = 30;
    rangedb[5].Distance = 100;
    rangedb[5].Color = "Red";
    rangedb[5].SpellName = "Out of Range";
    rangedb[5].DisplayName = TRLocale.OTHER.Too_Far;
  
  end

  if playerClass == "DRUID" then

    --Check Feral Charge
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(2,7);
    local hasFeralCharge = currRank;

    --Check Faerie Fire Feral
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(2,13);
    local hasFeralFaerie = currRank;
    
    --Check Nature's Reach
    local nameTalent, icon, tier, column, currRank, maxRank = GetTalentInfo(1,9);
    local NaturesReachBonus = 1 + currRank * .1;

    local nStance = GetShapeshiftForm(true);
    -- 1 = Bear/Dire Bear Form
    -- 2 = Aquatic Form
    -- 3 = Cat Form
    -- 4 = Travel Form
    -- 5 = Moonkin/Tree Form (flight form)
    -- 6 = Flight Form (?)

    if (nStance == 1) then
      rangedb[1].MinDistance = 0;
      rangedb[1].Distance = 5;
      rangedb[1].Color = "Green";
      rangedb[1].SpellName = TRLocale.DRUID.Bash ;
      rangedb[1].DisplayName = TRLocale.OTHER.Melee;
    elseif (nStance == 3) then
      rangedb[1].MinDistance = 0;
      rangedb[1].Distance = 5;
      rangedb[1].Color = "Green";
      rangedb[1].SpellName = TRLocale.DRUID.Claw;
      rangedb[1].DisplayName = TRLocale.OTHER.Melee;
    else
      rangedb[1].MinDistance = 0;
      rangedb[1].Distance = 5;
      rangedb[1].Action = 3;
      rangedb[1].IsAction = false;
      rangedb[1].Color = "Green";
      rangedb[1].SpellName = "Duel";
      rangedb[1].DisplayName = TRLocale.OTHER.Melee;
    end

    if (hasFeralCharge == 1) and (nStance == 1) then
      rangedb[2].MinDistance = 5;
      rangedb[2].Distance = 8;
      rangedb[2].Color = "Red";
      rangedb[2].SpellName = TRLocale.OTHER.Deadzone;
      rangedb[2].DisplayName = TRLocale.OTHER.Deadzone;

      rangedb[3].MinDistance = 8;
      rangedb[3].Distance = 25;
      rangedb[3].Color = "Yellow";
      rangedb[3].SpellName = TRLocale.DRUID.Feral_Charge;
      rangedb[3].DisplayName = TRLocale.DRUID.Feral_Charge;

      if (hasFeralFaerie == 1) then
        rangedb[4].MinDistance = 25;
        rangedb[4].Distance = 30 * NaturesReachBonus;
        rangedb[4].Color = "Orange";
        rangedb[4].SpellName = TRLocale.DRUID.Faerie_Fire;
        rangedb[4].DisplayName = TRLocale.DRUID.Faerie_Fire;
      else
        rangedb[4].MinDistance = 25;
        rangedb[4].Distance = 30 * NaturesReachBonus;
        rangedb[4].Color = "Orange";
        rangedb[4].SpellName = TRLocale.DRUID.Wrath;
        rangedb[4].DisplayName = TRLocale.OTHER.Too_Far;
      end
    elseif (nStance == 3) then
      if (hasFeralFaerie == 1) then
        rangedb[4].MinDistance = 5;
        rangedb[4].Distance = 30 * NaturesReachBonus;
        rangedb[4].Color = "Orange";
        rangedb[4].SpellName = TRLocale.DRUID.Faerie_Fire;
        rangedb[4].DisplayName = TRLocale.DRUID.Faerie_Fire;
      else
        rangedb[4].MinDistance = 5;
        rangedb[4].Distance = 30 * NaturesReachBonus;
        rangedb[4].Color = "Red";
        rangedb[4].SpellName = TRLocale.DRUID.Wrath;
        rangedb[4].DisplayName = TRLocale.OTHER.Too_Far;
      end
    else 
      rangedb[4].MinDistance = 5;
      rangedb[4].Distance = 30 * NaturesReachBonus;
      rangedb[4].Color = "Yellow";
      rangedb[4].SpellName = TRLocale.DRUID.Wrath;
      rangedb[4].DisplayName = TRLocale.DRUID.Wrath;
    end

    rangedb[5].MinDistance = 30 * NaturesReachBonus;
    rangedb[5].Distance = 100;
    rangedb[5].Color = "Red";
    rangedb[5].SpellName = "Out of Range";
    rangedb[5].DisplayName = TRLocale.OTHER.Too_Far;

  end



end

function TargetRange_GetRange()

-------------------------------
  local varMin = 0;
  local varMax = 0;
  local rangeColor = "";
  local rangeDisplayName = "";
  local startLoop = 1;
  local endLoop = 7;

  if not (UnitCanAttack("player", "playertarget")) then
    startLoop = 10;
    endLoop = 20;
  end

  --Action is in range
  for i= startLoop,endLoop do
    rangedb[i].InRange = false;
    rangedb[i].IsValid = false;

    if rangedb[i].IsAction  then
      local varInRange = IsSpellInRange(rangedb[i].SpellName);
      if (varInRange ~= nil) and (UnitIsDeadOrGhost("playertarget") ~= 1) then
        rangedb[i].IsValid = true;
        rangedb[i].InRange = (varInRange == 1); 
      end
      if (rangedb[i].SpellName == TRLocale.OTHER.Deadzone) then
        if (IsSpellInRange(TRLocale.HUNTER.Wing_Clip) ~= 1) 
          and (IsSpellInRange(TRLocale.HUNTER.Auto_Shot) ~= 1)
          and (CheckInteractDistance("target", 1) == 1) 
          and (UnitIsDeadOrGhost("playertarget") ~= 1) then
            rangedb[i].IsValid = true;
            rangedb[i].InRange = true;
        end
      end
      if (rangedb[i].SpellName == TRLocale.OTHER.Deadzone) then
        if (IsSpellInRange(TRLocale.DRUID.Bash) ~= 1) 
          and (IsSpellInRange(TRLocale.DRUID.Feral_Charge) ~= 1)
          and (CheckInteractDistance("target", 2) == 1) 
          and (IsSpellInRange(TRLocale.DRUID.Wrath) == 1)
          and (UnitIsDeadOrGhost("playertarget") ~= 1) then
            rangedb[i].IsValid = true;
            rangedb[i].InRange = true;
        end
      end
      if (rangedb[i].SpellName == "Out of Range") and (UnitIsDeadOrGhost("playertarget") ~= 1) and (UnitName("playertarget") ~= nil) then
        rangedb[i].IsValid = true;
        rangedb[i].InRange = true;        
      end 
    else
      local varInRange = CheckInteractDistance("target", rangedb[i].Action);
      rangedb[i].IsValid = true;
      if (varInRange ~= nil) and (UnitIsDeadOrGhost("playertarget") ~= 1) then
        rangedb[i].InRange =  (varInRange == 1);
      end
    end    

  end

  for i = endLoop,startLoop,-1 do
    if rangedb[i].IsValid then
      if rangedb[i].InRange then
        varMin = rangedb[i].MinDistance;
        varMax = rangedb[i].Distance;
        rangeColor = rangedb[i].Color;
        rangeDisplayName = rangedb[i].DisplayName;
      end
    end  
  end

  local varDistance = "N/A";

  if (varMax > 0) then
    varDistance = varMin.."-"..varMax.." ("..rangeDisplayName..")";
    if rangeColor == "Green" then
      TargetRangeWatchFrame1String1:SetTextColor(0.0, 1.0, 0.0); --Green
    elseif rangeColor == "Yellow" then
      TargetRangeWatchFrame1String1:SetTextColor(1.0, 1.0, 0.0); --Yellow
    elseif rangeColor == "Red" then
      TargetRangeWatchFrame1String1:SetTextColor(1.0, 0.0, 0.0); --Red
    elseif rangeColor == "Blue" then
      TargetRangeWatchFrame1String1:SetTextColor(0.0, 0.5, 0.5); --Blue
    elseif rangeColor == "Orange" then
      TargetRangeWatchFrame1String1:SetTextColor(1.0, 0.5, 0.0); --Orange
    else
      TargetRangeWatchFrame1String1:SetTextColor(0.7, 0.7, 0.7); --Gray
    end
  else
    TargetRangeWatchFrame1String1:SetTextColor(0.7, 0.7, 0.7);
  end

  TargetRange_RangeSize(varDistance);
  TargetRangeWatchFrame1String1:SetText(varDistance);

end


function TargetRange_TargetSize(aTargetLength)
  
  local DefaultNameLength = "";
  for i= 1,vardb.targetLength do
    DefaultNameLength = DefaultNameLength.."X";
  end

  if targetsTargetName ~= nil and string.len(targetsTargetName) > string.len(DefaultNameLength) then
    TargetRangeWatchFrame2:SetWidth(TargetRange_GetTextWidth(targetsTargetName) + 10);
  else
    TargetRangeWatchFrame2:SetWidth(TargetRange_GetTextWidth(DefaultNameLength) + 10);
  end

end

function TargetRange_RangeSize(aRangeText)
  
--  local TargetRangeLength = "XX-XXX";
  local TargetRangeLength = "XX";
  if (aRangeText ~= nil) and ( string.len(aRangeText) > string.len(TargetRangeLength) ) then
    TargetRangeLength = aRangeText;
  end

  TargetRangeWatchFrame1:SetWidth(TargetRange_GetTextWidth(TargetRangeLength) + 5);

end

function TargetRange_PrintStatus()
    
  for i= 1,7 do
    if rangedb[i].DisplayName ~= "N/A" then
      TargetRange_ChatMessage("Using: "..rangedb[i].SpellName.." Range: "..rangedb[i].MinDistance.."-"..rangedb[i].Distance);
    end
  end 
      
  TargetRange_ChatMessage("FontSize = "..vardb.textHeight);
  TargetRange_ChatMessage("Frame Alpha = "..vardb.alpha);
  TargetRange_ChatMessage("Update Interval = "..vardb.updateInterval);
  TargetRange_ChatMessage("Target Window Size = "..vardb.targetLength);
  if vardb.locked then
    TargetRange_ChatMessage("Frame Locked");
  else
    TargetRange_ChatMessage("Frame Not Locked");
  end
  if vardb.windowFade then
    TargetRange_ChatMessage("Window Fade: On");  
  else
    TargetRange_ChatMessage("Window Fade: Off");
  end    
  if vardb.targetShow or vardb.rangeShow then
    if vardb.rangeShow then
      TargetRange_ChatMessage("Range Window Enabled");
    else
      TargetRange_ChatMessage("Range Window Disabled");
    end

    if vardb.targetShow then
      TargetRange_ChatMessage("Target's Target Window Enabled");
    else
      TargetRange_ChatMessage("Target's Target Window Disabled");
    end
  else
    TargetRange_ChatMessage("Disabled");
  end
	
end


function TargetRange_GetTextWidth(text)

  TargetRangeWatchFrame1WidthTest:SetText(text);
  return TargetRangeWatchFrame1WidthTest:GetWidth()+10;

end


function TargetRange_Center()

  vardb.locked = false;
  TargetRange_Unlock(true);
  TargetRangeWatchFrame:ClearAllPoints();
  TargetRangeWatchFrame:SetPoint("CENTER", UIParent, "CENTER");
  TargetRangeWatchFrame1:ClearAllPoints();
  TargetRangeWatchFrame1:SetPoint("TOP", TargetRangeWatchFrame, "TOP");
  TargetRangeWatchFrame2:ClearAllPoints();
  TargetRangeWatchFrame2:SetPoint("TOP", TargetRangeWatchFrame1, "BOTTOM");
  if vardb.targetShow == false and vardb.rangeShow == false then
    vardb.targetShow = true;
    vardb.rangeShow = true;
    TargetRange_SetupUser();
  end

end

function TargetRange_Lock(PrintMsg)
  if PrintMsg then
    TargetRange_ChatMessage("Frame Locked");
  end
  TargetRangeWatchFrame:SetHeight(1);
  TargetRangeFade() ;
end

function TargetRange_Unlock(PrintMsg)
  if PrintMsg then
    TargetRange_ChatMessage("Frame Unlocked");
  end
  TargetRangeWatchFrame:SetHeight(55);
  TargetRangeFrame:Show();
  TargetRangeWatchFrame:Show();
end

function TargetRange_IsLocked()

  return vardb.locked;

end


--function TargetRange_IsEnabled()

--  return vardb.monitorCount ~= 0;

--end


--function RangeCheck_IsValidTarget()

--  return UnitName("target") ~= nil
--      and ( UnitCanAttack("player", "target") or (db.monitorPlayers and UnitPlayerControlled("target")) )
--      and UnitHealth("target") > 0;

--end

function TargetRange_SetTextHeight(aFontHeight)
  HRDebug("func: TargetRange_SetTextHeight - "..aFontHeight);
  local font = GameFontNormalSmall:GetFont();
  if aFontHeight then
      aFontHeight = tonumber(aFontHeight);
      if aFontHeight == nil then 
        aFontHeight = vardb.textHeight;
      end
      if aFontHeight > 0 and aFontHeight < 31 then
        vardb.textHeight = aFontHeight;
--	  getglobal("TargetRangeWatchFrame1String1"):SetFont("Fonts\\FRIZQT__.TTF", aFontHeight);
--	  getglobal("TargetRangeWatchFrame2String2"):SetFont("Fonts\\FRIZQT__.TTF", aFontHeight);
--	  TargetRangeWatchFrame1WidthTest:SetFont("Fonts\\FRIZQT__.TTF", aFontHeight);
	  getglobal("TargetRangeWatchFrame1String1"):SetFont(font, aFontHeight);
	  getglobal("TargetRangeWatchFrame2String2"):SetFont(font, aFontHeight);
	  TargetRangeWatchFrame1WidthTest:SetFont(font, aFontHeight);

	else
        TargetRange_ChatMessage(TARGETRANGE_TEXTHEIGHT_ERROR);
      end
  
  else
      TargetRange_ChatMessage(TARGETRANGE_TEXTHEIGHT_ERROR);
  end
  TargetRangeWatchFrame1:SetHeight((vardb.textHeight)+ 16);
  TargetRangeWatchFrame2:SetHeight((vardb.textHeight)+ 16);
  TargetRange_TargetSize(vardb.targetLength);
  TargetRange_RangeSize();

end

function TargetRange_SetTargetSize(aTargetLength)
  aTargetLength = tonumber(aTargetLength);
  if aTargetLength then
    vardb.targetLength = aTargetLength;
    if vardb.targetLength <= 1 then
      vardb.targetLength = 1;
    elseif vardb.targetLength >= 50 then
      vardb.targetLength = 50;
    end
  end
  TargetRange_TargetSize(vardb.targetLength);
end

function TargetRange_SetAlpha(aAlphaMsg)

  aAlphaMsg = tonumber(aAlphaMsg);
  if aAlphaMsg then
    vardb.alpha = aAlphaMsg;
    if vardb.alpha >= 1.0 then
      vardb.alpha = 1.0;
    elseif vardb.alpha <= 0.0 then
      vardb.alpha = 0.0;
    end
--	TargetRangeWatchFrame:SetAlpha(vardb.alpha);
    TargetRangeWatchFrame1:SetBackdropColor(0, 0, 0, vardb.alpha);
    TargetRangeWatchFrame2:SetBackdropColor(0, 0, 0, vardb.alpha);
  end

end

function TargetRange_SetUpdateInterval(aUpdateInterval)

  aUpdateInterval = tonumber(aUpdateInterval);
  if aUpdateInterval then
    vardb.updateInterval = aUpdateInterval;
    vardb.updateInterval = max(0, vardb.updateInterval);
  end

end

function HRDebug(aDebug)

  if varDebug then
    DEFAULT_CHAT_FRAME:AddMessage("|cffff0000" .. TARGETRANGE_NAME .. "Debug: " .. aDebug);
  end

end


function TargetRange_ChatMessage(msg)

  DEFAULT_CHAT_FRAME:AddMessage("|cffffff00" .. TARGETRANGE_NAME .. ": " .. msg);

end